@@ -83,12 +83,16 @@ class CloseDBExtranetAccessRequest(AbstractModel):
         """
         :param InstanceId: ID of instance for which to disable public network access. The ID is in the format of `tdsql-ow728lmc` and can be obtained through the `DescribeDBInstances` API.
         :type InstanceId: str
+        :param Ipv6Flag: Whether IPv6 is used. Default value: 0
+        :type Ipv6Flag: int
         """
         self.InstanceId = None
+        self.Ipv6Flag = None
 
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        self.Ipv6Flag = params.get("Ipv6Flag")
 
 
 class CloseDBExtranetAccessResponse(AbstractModel):
@@ -1946,12 +1950,16 @@ class OpenDBExtranetAccessRequest(AbstractModel):
         """
         :param InstanceId: ID of instance for which to enable public network access. The ID is in the format of `tdsql-ow728lmc` and can be obtained through the `DescribeDBInstances` API.
         :type InstanceId: str
+        :param Ipv6Flag: Whether IPv6 is used. Default value: 0
+        :type Ipv6Flag: int
         """
         self.InstanceId = None
+        self.Ipv6Flag = None
 
 
     def _deserialize(self, params):
         self.InstanceId = params.get("InstanceId")
+        self.Ipv6Flag = params.get("Ipv6Flag")
 
 
 class OpenDBExtranetAccessResponse(AbstractModel):
